Changelog
=========

0.3.1 - 2019-03-11
------------------

* Update packaging, source distribution now includes tests and wheel is universal


0.3.0 - 2019-03-07
------------------

* Improve display of test result by appending ::ISORT
* This release requires pytest 3.5


0.2.1 - 2018-09-11
------------------

* Drop "pytest-cache" dependency, not required anymore - part of py.test itself


0.2.0 - 2018-05-07
------------------

* Register marker to work with pytest's strict mode
* Add "official" support for Python 3.5 and 3.6


0.1.0 - 2015-03-23
------------------

* Initial release.
